@@ -316,6 +316,13 @@ pub fn common_impls(name: &syn::Ident, ref_type: &syn::Type) -> proc_macro2::Tok
                 ::std::ops::Deref::deref(self)
             }
         }
+
+        impl AsRef<str> for #name {
+            #[inline]
+            fn as_ref(&self) -> &str {
+                self.as_str()
+            }
+        }
     }
 }
 
@@ -348,6 +355,13 @@ fn infallible_conversion_impls(
             }
         }
 
+        impl ::std::borrow::Borrow<str> for #name {
+            #[inline]
+            fn borrow(&self) -> &str {
+                self.as_str()
+            }
+        }
+
         impl ::std::ops::Deref for #name {
             type Target = #ref_type;
 
@@ -395,6 +409,13 @@ fn fallible_conversion_impls(
             }
         }
 
+        impl ::std::borrow::Borrow<str> for #name {
+            #[inline]
+            fn borrow(&self) -> &str {
+                self.as_str()
+            }
+        }
+
         impl ::std::ops::Deref for #name {
             type Target = #ref_type;
 
@@ -498,6 +519,12 @@ fn conversion_impls(
                 }
             }
         }
+
+        impl<'a> From<#name> for ::std::borrow::Cow<'a, #ref_type> {
+            fn from(owned: #name) -> Self {
+                ::std::borrow::Cow::Owned(owned)
+            }
+        }
     }
 }
 
